//-----------------------------------------------------------------------------
//  Copyright (C) 2014-2015 Thomas S. Ullrich
//
//  This file is part of "MineSweeper".
//
//  This file may be used under the terms of the GNU General Public License.
//  This project is free software; you can redistribute it and/or modify it
//  under the terms of the GNU General Public License.
//
//  Author: Thomas S. Ullrich
//  Last update: July 29, 2014
//-----------------------------------------------------------------------------
#include "msCell.h"
#include <QGraphicsRectItem>
#include <QGraphicsSvgItem>
#include <QGraphicsPolygonItem>
#include <iostream>

using namespace std;

#define PR(x) cout << #x << " = " << (x) << endl;

msCell::msCell()
{
    mX = mY = 0;
    mIsMine = false;
    mIsFlaggedAsMine = false;
    mIsRevealed = false;
    mNumberOfNeighbors = 0;
    mWaterRect = 0;
    mFrameRect = 0;
    mNumberText = 0;
    mTryOutText = 0;
    mFlagSvg = 0;
    mMineSvg = 0;
    mCross = 0;
}

msCell::~msCell()
{
    delete mWaterRect;
    delete mFrameRect;
    delete mNumberText;
    delete mTryOutText;
    delete mFlagSvg;
    delete mMineSvg;
    delete mCross;
}

bool msCell::isMine() const {return mIsMine;}

bool msCell::isFlaggedAsMine() const {return mIsFlaggedAsMine;}

bool msCell::isCorrectlyFlaggedAsMine() const
{
    return (mIsFlaggedAsMine && mIsMine);
}

bool msCell::isRevealed() const {return mIsRevealed;}

unsigned int msCell::x() const {return mX;}

unsigned int msCell::y() const {return mY;}

unsigned int msCell::numberOfNeighbors() const {return mNumberOfNeighbors;}

QGraphicsRectItem*   msCell::waterRectangle()  {return mWaterRect;}

QGraphicsRectItem*   msCell::frameRectangle()  {return mFrameRect;}

QGraphicsSvgItem*   msCell::numberText()  {return mNumberText;}

QGraphicsSvgItem*   msCell::tryOutText()  {return mTryOutText;}

QGraphicsSvgItem* msCell::flagSvg()  {return mFlagSvg;}

QGraphicsSvgItem* msCell::mineSvg()  {return mMineSvg;}

QGraphicsPolygonItem* msCell::cross()  {return mCross;}

void msCell::setIsMine(bool val) {mIsMine = val;}

void msCell::setIsFlaggedAsMine(bool val) {
    mIsFlaggedAsMine = val;
    mFlagSvg->setVisible(mIsFlaggedAsMine);
}

void msCell::setIsRevealed(bool val) {
    mIsRevealed = val;
    if (mIsRevealed) mWaterRect->hide();
}

void msCell::setXY(unsigned int x, unsigned int y)
{
    mX = x; mY = y;
}

void msCell::setNumberOfNeighbors(unsigned int val) {mNumberOfNeighbors = val;}

void msCell::setWaterRect(QGraphicsRectItem* val) {mWaterRect = val;}

void msCell::setFrameRect(QGraphicsRectItem* val) {mFrameRect = val;}

void msCell::setNumberText(QGraphicsSvgItem* val) {mNumberText = val;}

void msCell::setTryOutText(QGraphicsSvgItem* val) {mTryOutText = val;}

void msCell::setFlagSvg(QGraphicsSvgItem* val) {mFlagSvg = val;}

void msCell::setMineSvg(QGraphicsSvgItem* val) {mMineSvg = val;}

void msCell::setCross(QGraphicsPolygonItem* val) {mCross = val;}


