//-----------------------------------------------------------------------------
//  Copyright (C) 2014-2015 Thomas S. Ullrich
//
//  This file is part of "MineSweeper".
//
//  This file may be used under the terms of the GNU General Public License.
//  This project is free software; you can redistribute it and/or modify it
//  under the terms of the GNU General Public License.
//
//  Author: Thomas S. Ullrich
//  Last update: July 29, 2014
//-----------------------------------------------------------------------------
#ifndef msCell_h
#define msCell_h

class QGraphicsRectItem;
class QGraphicsSvgItem;
class QGraphicsPolygonItem;

class msCell
{    
public:
    msCell();
    ~msCell();
    
    bool isMine() const;
    bool isFlaggedAsMine() const;
    bool isCorrectlyFlaggedAsMine() const;
    bool isRevealed() const;
    unsigned int x() const;
    unsigned int y() const;
    unsigned int numberOfNeighbors() const;

    QGraphicsRectItem*    waterRectangle();
    QGraphicsRectItem*    frameRectangle();
    QGraphicsSvgItem*     numberText();
    QGraphicsSvgItem*     tryOutText();
    QGraphicsSvgItem*     flagSvg();
    QGraphicsSvgItem*     mineSvg();
    QGraphicsPolygonItem* cross();

    void setIsMine(bool);
    void setIsFlaggedAsMine(bool);
    void setIsRevealed(bool);
    void setNumberOfNeighbors(unsigned int);
    void setXY(unsigned int, unsigned int);
    void setWaterRect(QGraphicsRectItem*);
    void setFrameRect(QGraphicsRectItem*);
    void setNumberText(QGraphicsSvgItem*);
    void setTryOutText(QGraphicsSvgItem*);
    void setFlagSvg(QGraphicsSvgItem*);
    void setMineSvg(QGraphicsSvgItem*);
    void setCross(QGraphicsPolygonItem*);    
    
private:
    bool mIsMine;
    bool mIsFlaggedAsMine;
    bool mIsRevealed;
    int  mNumberOfNeighbors;
    unsigned int mX;
    unsigned int mY;
    
    QGraphicsRectItem    *mWaterRect;
    QGraphicsRectItem    *mFrameRect;
    QGraphicsSvgItem     *mNumberText;
    QGraphicsSvgItem     *mFlagSvg;
    QGraphicsSvgItem     *mMineSvg;
    QGraphicsSvgItem     *mTryOutText;
    
    QGraphicsPolygonItem *mCross;
};

#endif

