//-----------------------------------------------------------------------------
//  Copyright (C) 2014-2016 Thomas S. Ullrich
//
//  This file is part of "MineSweeper".
//
//  This file may be used under the terms of the GNU General Public License.
//  This project is free software; you can redistribute it and/or modify it
//  under the terms of the GNU General Public License.
//
//  Author: Thomas S. Ullrich
//  Last update: May 3, 2016
//-----------------------------------------------------------------------------
#ifndef msSettings_h
#define msSettings_h

#include <QColor>
#include <QString>

class QSettings;
class msHighscoreList;

class msSettings
{
public:
    msSettings();
    ~msSettings();
    
public:
    void load();
    void save();
    
    QSettings* settings();
    
    static unsigned int numberOfCells();
    static QString mineFileName();
    static QString flagFileName();
    static QString tryOutSymbolFileName();
    static QString numberFileName(int);
    
    void setHighscoreList(msHighscoreList*);

public:
#if defined(Q_OS_WIN)
#undef small 
#endif
    enum class msGameSize { small = 0, medium, large, custom };
    enum class msMineType { mine1 = 0, mine2, mine3, bomb1, bomb2, bomb3 };
    enum class msFlagType { flag1 = 0, flag2, flag3, warning1, warning2, warning3 };
    
    //
    //  Restored and loaded from file
    //
    static unsigned int   mNumXCells;
    static unsigned int   mNumYCells;
    static unsigned int   mCellSize;
    static unsigned int   mNumberOfMines;
    static bool           mEasyStart;
    static bool           mAllowQuestionableFlag;
    static unsigned int   mNumberOfAllowedOopsies;
    
    static QColor mWaterColor;
    static QColor mBackgroundColor;
    
    static msMineType mCurrentMineType;
    static msFlagType mCurrentFlagType;
    static msGameSize mCurrentGameSize;
    static QString mLastPlayer;
    
    //
    //  Only used during the game, not stored
    //
    static unsigned int mMaxNumXCells;
    static unsigned int mMaxNumYCells;

    static int mMaxHighscoreItems;
    
    static QColor mWaterColorDefault;
    static QColor mBackgroundColorDefault;
    static unsigned int mCellSizeDefault;
    
    static unsigned int mSmallSizeParameters[3];
    static unsigned int mMediumSizeParameters[3];
    static unsigned int mLargeSizeParameters[3];
    
    static unsigned int mMinCellSize;
    static unsigned int mMaxCellSize;
    
private:
    QSettings *mSettings;
    msHighscoreList *mHighscoreList;
};

#endif